@@ -2,6 +2,9 @@ import os
 from configparser import ConfigParser
 from datetime import datetime
 from mroll.exceptions import InvalidWorkDirError
+import sqlparse
+from  abc  import  ABCMeta,  abstractmethod
+from typing import Tuple, List
 
 def gen_rev_id():
     import uuid
@@ -14,6 +17,8 @@ class Revision:
         self.ts = ts
         self.upgrade_sql = upgrade_sql
         self.downgrade_sql = downgrade_sql
+        self.upgrade_stmts = sqlparse.split(upgrade_sql) if upgrade_sql else []
+        self.downgrade_stmts = sqlparse.split(downgrade_sql) if downgrade_sql else []
 
     def __repr__(self):
         return "<Revision id={} description={}>".format(self.id, self.description)
@@ -77,31 +82,72 @@ class Revision:
             setattr(rev, 'description', description)
             setattr(rev, 'ts', ts)
             upgrade_sql = upgrade_sql.strip() or None
+            upgrade_stmts = sqlparse.split(upgrade_sql) if upgrade_sql else []
             setattr(rev, 'upgrade_sql', upgrade_sql)
+            setattr(rev, 'upgrade_stmts', upgrade_stmts)
             downgrade_sql = downgrade_sql.strip() or None
+            downgrade_stmts = sqlparse.split(downgrade_sql) if downgrade_sql else []
             setattr(rev, 'downgrade_sql', downgrade_sql)
+            setattr(rev, 'downgrade_stmts', downgrade_stmts)
             return rev
 
-
-class MigrationContext:
-    def __init__(self, head=None, revisions=[]):
-        self.head = head
-        self.revisions = revisions
+class MigrationCtxConfig:
+    db_name = None
+    username = None
+    password = None
+    hostname = None
+    port = None
+    tbl_name = None
 
     def __repr__(self):
-        return "<MigrationContext head={} revisions={}>".format(self.head, self.revisions)
+        return "<MigrationCtxConfig db_name={} tbl_name={}>".format(self.db_name, self.tbl_name)
 
-    @classmethod
-    def from_env(cls, env):
-        head = env.get_head()
-        if head is not None:
-            id_, description, ts = head
-            head = Revision(id_, description, ts)
-        revisions = [Revision(id_, description, ts) for id_, description, ts in env.get_revisions()]
-        mc = cls.__new__(cls)
-        mc.head = head
-        mc.revisions = revisions
-        return mc
+class MigrationContext(metaclass=ABCMeta):
+    """
+    Migrations Context Interface
+    """
+
+    @abstractmethod
+    def create_revisions_tbl(self):
+        pass
+
+    @property
+    @abstractmethod
+    def head(self) -> Revision:
+        pass
+
+    @property
+    @abstractmethod
+    def revisions(self) -> List[Revision]:
+        pass
+
+    @abstractmethod
+    def add_revisions(self, revisions: List[Revision]):
+        pass
+
+    @abstractmethod
+    def remove_revisions(self, revisions: List[Revision]):
+        pass
+
+# class MigrationContext:
+#     def __init__(self, head=None, revisions=[]):
+#         self.head = head
+#         self.revisions = revisions
+
+#     def __repr__(self):
+#         return "<MigrationContext head={} revisions={}>".format(self.head, self.revisions)
+
+#     @classmethod
+#     def from_env(cls, env):
+#         head = env.get_head()
+#         if head is not None:
+#             id_, description, ts = head
+#             head = Revision(id_, description, ts)
+#         revisions = [Revision(id_, description, ts) for id_, description, ts in env.get_revisions()]
+#         mc = cls.__new__(cls)
+#         mc.head = head
+#         mc.revisions = revisions
+#         return mc
 
 class WorkDirectory:
     def __init__(self, path):
@@ -112,12 +158,23 @@ class WorkDirectory:
         self.path = path
 
     @property
-    def config(self):
+    def config(self) -> MigrationCtxConfig:
         configfile = os.path.join(self.path, 'mroll.ini')
         config = ConfigParser()
         config.read(configfile)
         return config
 
+    def get_migration_ctx_config(self):
+        config = self.config
+        ctx_config = MigrationCtxConfig()
+        sections = config.sections()
+        for sec in sections:
+            options = config.options(sec)
+            for opt in options:
+                setattr(ctx_config, opt, config.get(sec, opt))
+        ctx_config.tbl_name = ctx_config.rev_history_tbl_name
+        return ctx_config
+
     def add_revision(self, rev: Revision):
         kebab = rev.description.strip().replace(' ', '_')
         fn = os.path.join(self.path, 'versions', '{}_{}.sql'.format(rev.id, kebab))
@@ -178,4 +235,4 @@ def get_all_upgrade_sql(work_dir=None):
             buf.write('\n')
         res = buf.getvalue()
     return res.strip()
-    
\ No newline at end of file
+    
